@@ -44,7 +44,7 @@ $EXPORT_TAGS{inet} = [qw(
 	inet_ntop
 )];
 
-$VERSION = do { sprintf "%d.%03d", (q$Revision: 1.15 $ =~ /\d+/g) };
+$VERSION = do { sprintf "%d.%03d", (q$Revision: 1.16 $ =~ /\d+/g) };
 
 bootstrap Net::Interface $VERSION;
 
@@ -1056,6 +1056,19 @@ results in the string "B<inet>" being printed.
 
 =back
 
+=head1 PREREQUISITES
+
+To build Net::Interface, it is necessary to have kernel development
+libriaries installed on the build system. Systems such as Ubuntu, FreeBSD,
+etc... do NOT come with these libraries installed.
+
+Your build system must have a fully populated directory
+
+    /usr/include/sys
+
+Missing header files in the above directory will produce errors saying that
+symbols such as AF_INET and PF_INET are missing.
+
 =head1 ACKNOWLEDGEMENTS
 
 This version of Net::Interface has been completely rewritten and updated to
