@@ -1,10 +1,10 @@
 #!/usr/bin/perl
 #
 # #####################################################################	#
-# netsymbols.pl	version 0.09	3-23-09, michael@bizsystems.com		#
+# netsymbols.pl	version 0.10	9-21-16, michael@bizsystems.com		#
 #									#
 #									#
-#     COPYRIGHT 2008-2009 Michael Robinton <michael@bizsystems.com>	#
+#     COPYRIGHT 2008-2016 Michael Robinton <michael@bizsystems.com>	#
 #									#
 # This program is free software; you can redistribute it and/or modify	#
 # it under the terms of either:						#
@@ -38,8 +38,43 @@
 #	http://www.gnu.org/copyleft/gpl.html.				#
 # #####################################################################	#
 
+package NetSymbols;
+use diagnostics;
 use Config;
-#use diagnostics;
+
+my $doprint = 0;
+
+my $conf = \%Config;
+
+my $include = $conf->{usrinc};
+
+sub new {
+  return bless {}, __PACKAGE__;
+}
+
+my $grep = qx/which grep/;
+chop $grep while $grep =~ /\n$/;
+
+my $gfp = sub {
+  my($mtch,$include) = @_;
+  my $cmd = $grep . $mtch . $include .'/*'."\n";
+  my @lines = qx/$cmd/;  
+  print STDERR '# ', $cmd if $doprint;
+  foreach (@lines) {
+    chop $_ while $_ =~ /\s$/;
+    print STDERR $_, "\n" if $doprint;
+  }
+  return @lines;
+};
+
+my (@fileAFs,@fileIFs,@fileIN6s);
+
+sub mksymblArrays {
+  @fileAFs  = $gfp->(' -rEl "define[[:space:]]+[AP]F_" ',$include);
+  @fileIFs  = $gfp->(' -rEl "define[[:space:]]+IF" ',$include);
+  @fileIN6s = $gfp->(' -rEl "define[[:space:]]+IN6_IF" ',$include);
+}
+
 ### generate AF/PF families 
 
 # list of troublesome symbols to ignore
@@ -104,18 +139,33 @@ sub cleanslurp {
   %slurped = ();
 }
 
+# file string, slurp switch full filename = 1
 sub slurp {
-  my $in = shift;
+  my($in,$sw) = @_;;
+  $sw = 0 unless defined $sw;
 #print STDERR "slurping $in\n";
   return if $slurped{$in};
   $slurped{$in} = 1;
   local *F;
-  open (F,$Config{usrinc} .'/'. $in) or return;
+  my $file = ($sw) ?
+	$in : $Config{usrinc} .'/'. $in;
+  open (F,$file) or return;
   my @new = <F>;
   close F;
+#foreach (@new) {
+#  print STDERR "$file => $_\n";
+#}
   push @slurp, @new;
 }
 
+sub fslurp {
+  foreach (@_) {
+#print STDERR $_,"\n";
+    slurp($_,1);	# tell slurp to use absolute file name
+  }
+}
+
+
 # input:	hash pointer,
 #		unique hash pointer or false
 #		regular expression,
@@ -126,6 +176,7 @@ sub fill {
   my %enum;				# enumeration cache
   foreach(@slurp) {
     if ($_ =~ /^#\s*include\s+\<\s*([^\s>]+)/) {
+#print STDERR "\tincfile $1\n";
       slurp($1);
       next;
     }
@@ -189,67 +240,94 @@ sub extradef {
   }
 }
 
+my $XX = 1;	# 1 = original, 0 = new
 
+sub gensyms {
+  mksymblArrays();
 
-cleanslurp();
-slurp('sys/socket.h');			# parse sys/socket.h and its #includes
-fill(\%fam,\%unique,'^#\s*define\s+((?:A|P)F_[^\s]+)\s+([^\s]+)');
+  cleanslurp();
+if ($XX) {
+  slurp('sys/socket.h');			# parse sys/socket.h and its #includes
+} else {
+  fslurp(@fileAFs);
+}
+  fill(\%fam,\%unique,'^#\s*define\s+((?:A|P)F_[^\s]+)\s+([^\s]+)');
+#  fill(\%fam,\%unique,'^#\s*define\s+((?:A|P)F_[^\s]{2,})\s+([^\s]+)');
 # repeat in case symbol dependencies are out of order
-cleanslurp();
-slurp('sys/socket.h');
-fill(\%fam,'','^#\s*define\s+((?:A|P)F_[^\s]+)\s+([^\s]+)');
+  cleanslurp();
+if ($XX) {
+  slurp('sys/socket.h');
+#slurp('sys/types.h');
+} else {
+  fslurp(@fileAFs);
+}
+  fill(\%fam,'','^#\s*define\s+((?:A|P)F_[^\s]+)\s+([^\s]+)');
+#  fill(\%fam,'','^#\s*define\s+((?:A|P)F_[^\s]{2,})\s+([^\s]+)');
 
 
+  my %ifs;
+  cleanslurp();
+if ($XX) {
+  slurp('net/if.h');
+  slurp('netinet/in.h') if -e '/usr/include/netinet/in.h';
+  slurp('netinet/in_var.h') if -e '/usr/include/netinet/in_var.h';
+} else {
+  fslurp(@fileIFs);
+  fslurp(@fileIN6s);
+}
+  fill(\%ifs,\%unique,'^#\s*define\s+(IF[^\s]+)\s+([^\s]+)','(IF[^\s]+)\s*\=\s*([^\s,]+)');
+  fill(\%ifs,\%unique,'^#\s*define\s+(IN6_IF[^\s]+)\s+([^\s]+)','(IN6_IF[^\s]+)\s*\=\s*([^\s,]+)');
 
-my %ifs;
-cleanslurp();
-slurp('net/if.h');
-slurp('netinet/in.h') if -e '/usr/include/netinet/in.h';
-slurp('netinet/in_var.h') if -e '/usr/include/netinet/in_var.h';
-fill(\%ifs,'','^#\s*define\s+(IF[^\s]+)\s+([^\s]+)','(IF[^\s]+)\s*\=\s*([^\s,]+)');
-fill(\%ifs,'','^#\s*define\s+(IN6_IF[^\s]+)\s+([^\s]+)','(IN6_IF[^\s]+)\s*\=\s*([^\s,]+)');
-
-slurp('net/if.h');
-slurp('netinet/in.h') if -e '/usr/include/netinet/in.h';
-slurp('netinet/in_var.h') if -e '/usr/include/netinet/in_var.h';
-fill(\%ifs,'','^#\s*define\s+(IF[^\s]+)\s+([^\s]+)','(IF[^\s]+)\s*\=\s*([^\s,]+)');
-fill(\%ifs,'','^#\s*define\s+(IN6_IF[^\s]+)\s+([^\s]+)','(IN6_IF[^\s]+)\s*\=\s*([^\s,]+)');
+#foreach (keys %unique) {
+#print STDERR "$_\t=> $unique{$_}\n";
+#}
+  cleanslurp();
+if ($XX) {
+  slurp('net/if.h');
+  slurp('netinet/in.h') if -e '/usr/include/netinet/in.h';
+  slurp('netinet/in_var.h') if -e '/usr/include/netinet/in_var.h';
+} else {
+  fslurp(@fileIFs);
+  fslurp(@fileIN6s);
+}
+  fill(\%ifs,'','^#\s*define\s+(IF[^\s]+)\s+([^\s]+)','(IF[^\s]+)\s*\=\s*([^\s,]+)');
+  fill(\%ifs,'','^#\s*define\s+(IN6_IF[^\s]+)\s+([^\s]+)','(IN6_IF[^\s]+)\s*\=\s*([^\s,]+)');
 
 # dispose of troublesome symbols
-my %ru = reverse %unique;
-foreach my $symhsh (\%ifs,\%fam,\%ru) {
-  foreach(@donotuse) {		# remove the ones that cause trouble
-    delete $symhsh->{$_} if exists $symhsh->{$_};
-  }
-}
-foreach my $symhsh(\%fam) {
-  my @allsyms = keys %$symhsh;
-  foreach my $havsym (@allsyms) {
-    unless (grep {/$havsym/} @wantafsyms) {
-      delete $symhsh->{$havsym};	# delete unneeded symbol here
-      delete $ru{$havsym};		# and in unique hash
+  my %ru = reverse %unique;
+  foreach my $symhsh (\%ifs,\%fam,\%ru) {
+    foreach(@donotuse) {		# remove the ones that cause trouble
+      delete $symhsh->{$_} if exists $symhsh->{$_};
     }
   }
-}
-%unique = reverse %ru;
+  foreach my $symhsh(\%fam) {
+    my @allsyms = keys %$symhsh;
+    foreach my $havsym (@allsyms) {
+      unless (grep {/$havsym/} @wantafsyms) {
+        delete $symhsh->{$havsym};	# delete unneeded symbol here
+        delete $ru{$havsym};		# and in unique hash
+      }
+    }
+  }
+  %unique = reverse %ru;
 
 # fill done, bump max value
-++$endv;
+  ++$endv;
 # we're going to ignore all that end value tracking because IFF's exceed I32
 # I32 size. Use the max number that fits in an I32 and do IFF's another way
-$endv = (2**31) -1;
+  $endv = (2**31) -1;
 
-mkdir 'lib' unless -e 'lib' && -d 'lib';
-mkdir 'lib/Net' unless -e 'lib/Net' && -d 'lib/Net';
-mkdir 'lib/Net/Interface' unless -e 'lib/Net/Interface' && -d 'lib/Net/Interface';
+  mkdir 'lib' unless -e 'lib' && -d 'lib';
+  mkdir 'lib/Net' unless -e 'lib/Net' && -d 'lib/Net';
+  mkdir 'lib/Net/Interface' unless -e 'lib/Net/Interface' && -d 'lib/Net/Interface';
 
-open(NFe,'>lib/Net/Interface/NetSymbols.pm') or die "could not open NetSymbols.pm for write";
-open(NFx,'>netsymbolXS.inc') or die "could not open netsymbolXS.inc for write";
-open(NFc,'>netsymbolC.inc') or die "could not open netsymbolC.inc for write";
-open(NFt,'>ni_IFF_inc.c') or die "could not open ni_IFF_inc.c for write";
-open(NFz,'>ni_XStabs_inc.c') or die "could not open ni_XStabs_inc.c for write";
+  open(NFe,'>lib/Net/Interface/NetSymbols.pm') or die "could not open NetSymbols.pm for write";
+  open(NFx,'>netsymbolXS.inc') or die "could not open netsymbolXS.inc for write";
+  open(NFc,'>netsymbolC.inc') or die "could not open netsymbolC.inc for write";
+  open(NFt,'>ni_IFF_inc.c') or die "could not open ni_IFF_inc.c for write";
+  open(NFz,'>ni_XStabs_inc.c') or die "could not open ni_XStabs_inc.c for write";
 
-print NFz q|/*	BEGIN ni_XStabs_inc.c
+  print NFz q|/*	BEGIN ni_XStabs_inc.c
  * ************************************************************	*
  *	DO NOT ALTER THIS FILE					*
  *	IT IS WRITTEN BY Makefile.PL & inst/netsymbols.pl	*
@@ -260,28 +338,28 @@ print NFz q|/*	BEGIN ni_XStabs_inc.c
 
 |;
 # make defines for synonyms
-extradef(*NFc,\%fam,qw( PF_LOCAL PF_UNIX PF_FILE AF_LOCAL AF_FILE AF_UNIX )); # are all synonyms
-extradef(*NFc,\%fam,qw( PF_MAX AF_MAX ));
-extradef(*NFc,\%fam,qw( AF_PACKET PF_PACKET AF_ROUTE PF_ROUTE ));
-extradef(*NFc,\%fam,qw( AF_ISO PF_ISO AF_BRIDGE PF_BRIDGE ));
+  extradef(*NFc,\%fam,qw( PF_LOCAL PF_UNIX PF_FILE AF_LOCAL AF_FILE AF_UNIX )); # are all synonyms
+  extradef(*NFc,\%fam,qw( PF_MAX AF_MAX ));
+  extradef(*NFc,\%fam,qw( AF_PACKET PF_PACKET AF_ROUTE PF_ROUTE ));
+  extradef(*NFc,\%fam,qw( AF_ISO PF_ISO AF_BRIDGE PF_BRIDGE ));
 # this one is not correct...  extradef(*NFc,\%fam,qw( AF_NS PF_NS AF_NUTSS PF_NUTSS AF_ATM PF_ATM ));
 
-extradef(*NFc,\%ifs,qw( IFNAMSIZ IF_NAMESIZE ));
+  extradef(*NFc,\%ifs,qw( IFNAMSIZ IF_NAMESIZE ));
 
 # Fix missing definition
-print NFc "#ifndef IFHWADDRLEN\n#define IFHWADDRLEN 6\n#endif\n";
-$ifs{IFHWADDRLEN} = 6;
+  print NFc "#ifndef IFHWADDRLEN\n#define IFHWADDRLEN 6\n#endif\n";
+  $ifs{IFHWADDRLEN} = 6;
 
 # Add opening definition
-print NFc qq|
+  print NFc qq|
 #define __NI_AF_TEST $endv
 |;
-print NFz q|
+  print NFz q|
 const ni_iff_t ni_af_sym_tab[] = {
 |;
 ### populate exports
 
-print NFe q|#!|. $Config{perlpath} .q|
+  print NFe q|#!|. $conf->{perlpath} .q|
 #
 # DO NOT ALTER THIS FILE
 # IT IS WRITTEN BY Makefile.PL and inst/netsymbols.pl
@@ -294,14 +372,14 @@ $VERSION = 1.01;
 
 |;
 
-print NFx q|void
+  print NFx q|void
 _net_af_syms()
     ALIAS:
 |;
 
 ### populate IFF flags
 #
-print NFt q|
+  print NFt q|
 /*	BEGIN ni_IFF_inc.c	include
  ****************************************************************
  *	DO NOT ALTER THIS FILE					*
@@ -315,41 +393,45 @@ const ni_iff_t ni_iff_tab[] = {
 
 ### populate C portion
 #
-my @tmp = grep {/^AF/} keys %fam;	# tmp store AFs
-my @afs = sort { $fam{$a} <=> $fam{$b} } @tmp;
+  my @tmp = grep {/^AF/} keys %fam;	# tmp store AFs
+  my @afs = sort { $fam{$a} <=> $fam{$b} } @tmp;
 
-@tmp = grep {/^PF/} keys %fam;
-my @pfs = sort { $fam{$a} <=> $fam{$b} } @tmp;
+  @tmp = grep {/^PF/} keys %fam;
+  my @pfs = sort { $fam{$a} <=> $fam{$b} } @tmp;
 
-my @ifs = keys %ifs;
+  my @ifs = keys %ifs;
 # iffs are not unique so we can safely purge unwanted symbols here
-my @iffs = sort grep {/^IFF_/ && $_ !~ /IFF_DRV/} keys %ifs;
-my @iffIN6 = sort grep {/^IN6_IFF/} keys %ifs;
+  my @iffs = sort grep {/^IFF_/ && $_ !~ /IFF_DRV/} keys %ifs;
+  my @iffIN6 = sort grep {/^IN6_IFF/} keys %ifs;
 
-print NFe q|my @afs = qw(
+#foreach (@iffs) {
+#  print STDERR "$_\t=> $ifs{$_}\n";
+#}
+  print NFe q|my @afs = qw(
 |;
-foreach(@afs) {
-  $_ =~ /AF_([^\s]+)/;
-  print NFx "\t$_ = _NI_$_\n";
-  print NFe "\t$_\n";
-  print NFc qq|#ifdef $_\n\# define _NI_$_ $fam{$_}\n#else\n# define _NI_$_ $endv\n#endif\n|;
-  print NFz qq|\t{$_,\t"|, (lc $1), qq|"},\n|;
-}
-print NFe q|);
+
+  foreach(@afs) {
+    $_ =~ /AF_([^\s]+)/;
+    print NFx "\t$_ = _NI_$_\n";
+    print NFe "\t$_\n";
+    print NFc qq|#ifdef $_\n\# define _NI_$_ $fam{$_}\n#else\n# define _NI_$_ $endv\n#endif\n|;
+    print NFz qq|\t{$_,\t"|, (lc $1), qq|"},\n|;
+  }
+  print NFe q|);
 my @pfs = qw(
 |;
-foreach(@pfs) {
-  $_ =~ /PF_([^\s]+)/;
-  print NFx "\t$_ = _NI_$_\n";
-  print NFe "\t$_\n";
-  print NFc qq|#ifdef $_\n\# define _NI_$_ $fam{$_}\n#else\n# define _NI_$_ $endv\n#endif\n|;
-  print NFz qq|\t{$_,\t"|, (lc $1), qq|"},\n|;
-}
-print NFz qq|\t{__NI_AF_TEST,\t"placeholder"}
+  foreach(@pfs) {
+    $_ =~ /PF_([^\s]+)/;
+    print NFx "\t$_ = _NI_$_\n";
+    print NFe "\t$_\n";
+    print NFc qq|#ifdef $_\n\# define _NI_$_ $fam{$_}\n#else\n# define _NI_$_ $endv\n#endif\n|;
+    print NFz qq|\t{$_,\t"|, (lc $1), qq|"},\n|;
+  }
+  print NFz qq|\t{__NI_AF_TEST,\t"placeholder"}
 };
 |;
 
-print NFx qq|\t_NI_AF_TEST = __NI_AF_TEST
+  print NFx qq|\t_NI_AF_TEST = __NI_AF_TEST
     PREINIT:
 	SV * rv;
 	int n, i;
@@ -375,35 +457,35 @@ _net_if_syms()
     ALIAS:
 |;
 
-print NFe q|);
+  print NFe q|);
 my @ifs = qw(
 |;
 
-my $ifidx = 0;
-my $idxary = q|
+  my $ifidx = 0;
+  my $idxary = q|
 const u_int64_t bigsymvals[] = {|;
-my $icoma = '';
+  my $icoma = '';
 
-foreach (@ifs) {
-  print NFe "\t$_\n";
-  next if $_ =~ /IFF_/;
-  print NFc qq|#ifdef $_\n\# define _NI_$_ $_\n#else\n# define _NI_$_ $endv\n#endif\n|;
+  foreach (@ifs) {
+    print NFe "\t$_\n";
+    next if $_ =~ /IFF_/;
+    print NFc qq|#ifdef $_\n\# define _NI_$_ $_\n#else\n# define _NI_$_ $endv\n#endif\n|;
 #  print NFx "\t$_ = _NI_$_\n";
-  print NFx "\t$_ = $ifidx\n";
-  $idxary .= "$icoma\n\t$ifs{$_}";
-  $icoma = ',';
-  $ifidx++;
-}
+    print NFx "\t$_ = $ifidx\n";
+    $idxary .= "$icoma\n\t$ifs{$_}";
+    $icoma = ',';
+    $ifidx++;
+  }
 
-print NFz qq|
+  print NFz qq|
 const ni_iff_t ni_sym_iff_tab[] = {
 |;
 
-print NFe q|);
+  print NFe q|);
 my @iffs = qw(
 |;
 
-print NFx qq|    CODE:
+  print NFx qq|    CODE:
 	if (ix >= $endv) {
 	    croak("%s is not implemented on this architecture", GvNAME(CvGV(cv)));
 	}
@@ -417,68 +499,68 @@ _net_i2f_syms()
     ALIAS:
 |;
 
-$comma = '';
-foreach(sort @iffs) {
-  $_ =~ /IFF_([^\s]+)/;
-  print NFc qq|#ifdef $_\n\# define _NI_$_ $_\n#else\n# define _NI_$_ $endv\n#endif\n|;
-  print NFz qq|\t{$_,\t"|, (lc $1), qq|"},\n|;
-  print NFe "\t$_\n";
+  $comma = '';
+  foreach(sort @iffs) {
+    $_ =~ /IFF_([^\s]+)/;
+    print NFc qq|#ifdef $_\n\# define _NI_$_ $_\n#else\n# define _NI_$_ $endv\n#endif\n|;
+    print NFz qq|\t{$_,\t"|, (lc $1), qq|"},\n|;
+    print NFe "\t$_\n";
 #  print NFx "\t$_ = _NI_$_\n";
-  print NFx "\t$_ = $ifidx\n";
-  $idxary .= "$icoma\n\t$ifs{$_}";
-  $ifidx++;
-  next if $_ eq 'IFF_UP';	# special case handled separately
-  print NFt qq|$comma\n\t\{$_,\t"$1"\}|;
-  $comma = ',';
-}
-print NFt q|
+    print NFx "\t$_ = $ifidx\n";
+    $idxary .= "$icoma\n\t$ifs{$_}";
+    $ifidx++;
+    next if $_ eq 'IFF_UP';	# special case handled separately
+    print NFt qq|$comma\n\t\{$_,\t"$1"\}|;
+    $comma = ',';
+  }
+  print NFt q|
 };
 
 #ifdef HAVE_STRUCT_IN6_IFREQ
 const ni_iff_t ni_iff_tabIN6[] = {
 |;
 
-print NFe q|);
+  print NFe q|);
 my @iffIN6 = qw(
 |;
 
-$comma = '';
-foreach(sort @iffIN6) {
-  $_ =~ /IFF_([^\s]+)/;
-  print NFc qq|#ifdef $_\n\# define _NI_$_ $_\n#else\n# define _NI_$_ $endv\n#endif\n|;
-  print NFz qq|\t{$_,\t"|. (lc $1). qq|"},\n|;
-  next if $_ eq 'IFF_UP';	# special case handled separately
-  print NFe "\t$_\n";
+  $comma = '';
+  foreach(sort @iffIN6) {
+    $_ =~ /IFF_([^\s]+)/;
+    print NFc qq|#ifdef $_\n\# define _NI_$_ $_\n#else\n# define _NI_$_ $endv\n#endif\n|;
+    print NFz qq|\t{$_,\t"|. (lc $1). qq|"},\n|;
+    next if $_ eq 'IFF_UP';	# special case handled separately
+    print NFe "\t$_\n";
 #  print NFx "\t$_ = _NI_$_\n";
-  print NFx "\t$_ = $ifidx\n";
-  $idxary .= "$icoma\n\t$ifs{$_}";
-  $ifidx++;
-  print NFt qq|$comma\n\t\{$_,\t"$1"\}|;
-  $comma = ',';
-}
-print NFz qq|\t{__NI_AF_TEST,\t"placeholder"}
+    print NFx "\t$_ = $ifidx\n";
+    $idxary .= "$icoma\n\t$ifs{$_}";
+    $ifidx++;
+    print NFt qq|$comma\n\t\{$_,\t"$1"\}|;
+    $comma = ',';
+  }
+  print NFz qq|\t{__NI_AF_TEST,\t"placeholder"}
 };
 
 $idxary
 };
 |;
 
-print NFt q|
+  print NFt q|
 };
 #endif
 /*	END ni_IFF_inc.c	include		*/
 |;
 
-print NFe q|);
+  print NFe q|);
 my %unique = (
 |;
 
-my $utxt = '';
-foreach(sort {$a <=> $b} keys %unique) {
-  $utxt .= "\t$_\t=> '". $unique{$_} ."',\n";
-}
+  my $utxt = '';
+  foreach(sort {$a <=> $b} keys %unique) {
+    $utxt .= "\t$_\t=> '". $unique{$_} ."',\n";
+  }
 
-print NFe $utxt, q|);
+  print NFe $utxt, q|);
 
 my @iftype = qw(
     IPV6_ADDR_ANY
@@ -560,7 +642,7 @@ use Net::Interface qw(
 	Net::Interface::NetSymbols::NI_UNIQUE();
 |;
 
-print NFe qq|@afs
+  print NFe qq|@afs
 
 @pfs
 
@@ -569,23 +651,22 @@ print NFe qq|@afs
 @iffs
 |;
 
-if (@iffIN6) {
-  print NFe qq|
+  if (@iffIN6) {
+    print NFe qq|
 @iffIN6	populated for BSD flavored systems
 
 :all :afs :pfs :ifs :iffs :iffIN6 :iftype :scope
 
 );
 |;
-} else {
-  print NFe qq|
+  } else {
+    print NFe qq|
 :all :afs :pfs :ifs :iffs :iftype :scope
 
 );
 |;
-}
-
-print NFe q|
+  }
+  print NFe q|
 =head1 DESCRIPTION
 
 All of the AF_XXX and PF_XXX symbols available in local C<sys/socket.h> plus
@@ -613,8 +694,8 @@ To print the numeric value of the SYMBOL do:
 
 |;
 
-if (exists $fam{AF_INET6}) {
-  print NFe q|On systems supporting IPV6, these additional symbols are available which
+  if (exists $fam{AF_INET6}) {
+    print NFe q|On systems supporting IPV6, these additional symbols are available which
 may be applied to the address I<type> to determine the address attributes.
 
     IPV6_ADDR_ANY		unknown
@@ -659,9 +740,9 @@ These symbols may be equated to the I<scope> of the address.
     }
 
 |;
-}
+  }
 
-print NFe q|
+  print NFe q|
 =over 4
 
 =item * :all	Import all symbols
@@ -675,21 +756,21 @@ print NFe q|
 =item * :iffs	Import all IFF symbols
 |;
 
-if (@iffIN6) {
-print NFe q|
+  if (@iffIN6) {
+    print NFe q|
 =item * :iffIN6	Import all IN6_IFF symbols (BSD flavors only)
 |;
-}
+  }
 
-if (exists $fam{AF_INET6}) {
-  print NFe q|
+  if (exists $fam{AF_INET6}) {
+    print NFe q|
 =item * :iftype	Import all IPV6 type symbols
 
 =item * :scope	Import all IPV6 scope symbols
 |;
-}
+  }
 
-print NFe q|
+  print NFe q|
 =back
 
 =head1 non EXPORT functions
@@ -722,7 +803,7 @@ the same terms as Perl itself.
 |;
 
 # add test element and complete
-print NFx qq|    PREINIT:
+  print NFx qq|    PREINIT:
 	SV * rv;
 	int n, i;
     PPCODE:
@@ -746,8 +827,11 @@ print NFx qq|    PREINIT:
 # usually _LOCAL is defined on modern systems
 #
 
-close NFe;
-close NFx;
-close NFc;
-close NFt;
+  close NFe;
+  close NFx;
+  close NFc;
+  close NFt;
+#  exit;
+}
+gensyms();
 1;
